<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009 Tim Lochmueller <webmaster@fruit-lab.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * Automator registry class for handle the action steps
 *
 * @author	Tim Lochmueller <webmaster@fruit-lab.de>
 * @package	TYPO3
 */
class tx_automator_Registry {

	
	/**
	 * Store the Step data.
	 * For access use the registerSteps and getSteps functions
	 */
	static protected $registerSteps = array();
	
	
	/**
	 * Register a new step at the automator.
	 * implement this in every start script in the TYPO3 start process
	 * 
	 * @param	String	The name of the Step. A normale String or an LLL: String
	 * @param	String	The absoulte file location including the TYPO3 Syntax for the class name "...->classname"
	 * @param	String	The category for the backend. This ist only for a better overview in the backend
	 */
	public function registerStep($name, $location, $category = 'ext'){
		
		// Create category
		if(!isset(tx_automator_Registry::$registerSteps[$category]))
			tx_automator_Registry::$registerSteps[$category] = array();
		
		// Create Select Key
		$parts = explode('/', $location);
		$selectKey = $parts[sizeof($parts)-1];
		
		// Find XML configuration
		$parts = explode('->', $location);
		$xml = str_replace('.php', '.xml', $parts[0]);
		
		// Register xml File
		if(file_exists($xml)) {
			global $TCA;
			t3lib_div::loadTCA('tx_automator_steps');
			$TCA['tx_automator_steps']['columns']['configuration']['config']['ds'][$selectKey] = file_get_contents($xml);
		} 
		
		
		// Register function
		tx_automator_Registry::$registerSteps[$category][] = array('name' => $name, 'selectKey' => $selectKey, 'location' => $location);
	}
	
	
	/**
	 * Get all registert steps
	 * 
	 * @return	array The complete Step Array
	 */
	public function getSteps(){
		return tx_automator_Registry::$registerSteps;
	}
	
	
} # class - tx_automator_Registry

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/classes/class.tx_automator_Registry.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/classes/class.tx_automator_Registry.php']);
} # if
?>