<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2009 Tim Lochmueller <webmaster@fruit-lab.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/


/**
 * Automator runner for runnig a action
 *
 * @author	Tim Lochmueller <webmaster@fruit-lab.de>
 * @package	TYPO3
 */
class tx_automator_Runner {
	
	
	/**
	 * With the step delay you can debug the extension
	 * Every redirect will wait the step delay. Default value is 750 (ms)
	 */
	static protected $stepDelay = 750;
	
	
	/**
	 * The ID of the running action
	 */
	static protected $runID = null;
	
	
	public function start($runID){
		$this->runID = $runID;
		$this->storageData = $this->getRunData($this->runID);
		$this->currentStep = ($this->storageData['running']['lastStep']+1);	
	}
	
	public function finish(){
		$this->storageData['running']['lastStep'] = $this->currentStep;
		$this->safeRunData($this->runID,$this->storageData);
	}
	
	public function getNumberOfAllSteps(){
		return count($this->storageData['steps']);	
	}
	
	
	/**
	 * Set the deleay of the step functions
	 * 
	 * @param	int		The time in ms of the timeout
	 */
	public function setDelay($ms){
		$this->stepDelay = $ms;
	} 
	
	
	/**
	 * Get the number of the current step
	 * To get the next step inkrement this number
	 * Attation: Steps starts with 0
	 * 
	 * @return	int		The number of the current step
	 */
	public function getCurrentStepNumber(){
		return $this->currentStep;
	}
	
	
	/**
	 * Get the ID of the current run. Every run have a uniq id to allow multiple
	 * runnings of same actions in one installation
	 * 
	 * @param	String	The running ID
	 */
	public function getCurrentRunId(){
		return $this->runID;
	}
	
	
	/**
	 * Get the javascript for the next Step
	 * Use this function if you only move forward
	 * 
	 * @return	String	HTML Code in <script>-Tags
	 */
	public function getJsNextStep(){
		$currentStep = $this->getCurrentStep();
		return $this->geetJsStep($currentStep+1);
	}
	
	
	/**
	 * Return the URL to the next step
	 * If there are no more steps, the step ID will be "finish"
	 * 
	 * @return	String	The URL to the next Step
	 */
	private function getStepUrl() {
		return 'ajax.php?ajaxID=tx_automator_Ajax::runAction&runID='.$this->getCurrentRunId();
	}
	
	
	/**
	 * Get the javascript for the given Step
	 * Use this function if you jump back in the actions
	 * 
	 * @return	String	HTML Code in <script>-Tags
	 */
	public function getJsStep() {
		$out = '<script type="text/javascript">
			window.setTimeout(function(){ document.location.href = "'.$this->getStepUrl().'"; }, '.$this->stepDelay.');
			</script>';
		return $out;
	}
	
	
	private function loadActionConfiguration(){
		
		
	}
	
	public function startAction($actionID){
		$rows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('uid,title', 'tx_automator_actions', 'uid='.intval($actionID), '', '', 1);
		if(!sizeof($rows)) return false;
		
		$this->removeDataOlderThan();
		$runID = t3lib_div::shortMD5($rows[0]['uid'].$rows[0]['title'].time());
		$rows[0]['starttime'] = time();
		
		
		$data = array(
			'meta' => $rows[0],
			'steps' => $GLOBALS['TYPO3_DB']->exec_SELECTgetRows('*', 'tx_automator_steps', 'actionuid='.intval($actionID), '', 'sorting'),
			'running' => array(
				'lastStep' => -1,
				'logicStack' => array(),
				'stepCounter' => 0,
			),
		);
		
		$this->safeRunData($runID, $data);
		return $runID;
	}
	
	public function safeRunData($key, array $data) {
		$GLOBALS['BE_USER']->uc['tx_autmator'][$key] = $data;
		$GLOBALS['BE_USER']->writeUC();	
	}
	
	public function getRunData($key) {
		if(isset($GLOBALS['BE_USER']->uc['tx_autmator'][$key]))
			return $GLOBALS['BE_USER']->uc['tx_autmator'][$key];
		return false;	
	}
	
	private function removeDataOlderThan($timeInSeconds = 3600) {
		
	}
	
	
	public function runUpcommingStep(){
		
		
	}
	
	public function loadStep($number) {
		
		// Step indentifizieren und aus Datenbank holen
		
		// Parameter berprfen
	}
	
	public function setInputParameter(){
		
		
	}
	
	public function runStep(){
		
		
	}
	
	public function storeOutputData(){
		
		
	}

} # class - tx_automator_Runner

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/classes/class.tx_automator_Runner.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/classes/class.tx_automator_Runner.php']);
} # if
?>