<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2008-2009 Steffen Kamper <info@sk-typo3.de>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

	// load the language file
$GLOBALS['LANG']->includeLLFile('EXT:automator/locallang_db.xml');

/**
 * Adds action links to the backend's toolbar
 *
 * @author	Steffen Kamper <info@sk-typo3.de>
 * @package TYPO3
 * @subpackage tx_sysaction
 */
class tx_automator_ToolBarMenu implements backend_toolbarItem {

	/**
	 * reference back to the backend object
	 *
	 * @var	TYPO3backend
	 */
	protected $backendReference;
	protected $EXTKEY = 'automator';

	/**
	 * constructor
	 *
	 * @return	void
	 */
	public function __construct(TYPO3backend &$backendReference = null) {
		$this->backendReference = $backendReference;
	}

	/**
	 * sets the backend reference
	 *
	 * @param	TYPO3backend	backend object reference
	 * @return	void
	 */
	public function setBackend(TYPO3backend &$backendReference) {
		$this->backendReference = $backendReference;
	}

	/**
	 * renders the toolbar menu
	 *
	 * @return	string	the rendered backend menu
	 * @author	Ingo Renner <ingo@typo3.org>
	 */
	public function render() {
		$actionMenu    = array();
		$actionEntries = $this->getActionEntries();

		if ($actionEntries) {
			$this->addJavascriptToBackend();
			$this->addCssToBackend();
			$title = $GLOBALS['LANG']->getLL('action_toolbaritem', true);

			$actionMenu[] = '<a href="#" class="toolbar-item"><img' .
				t3lib_iconWorks::skinImg(
					$this->backPath,
					t3lib_extMgm::extRelPath($this->EXTKEY) . 'ext_icon.gif',
					'width="16" height="16"'
				) . ' title="' . $title . '" alt="' . $title . '" /></a>';

			$actionMenu[] = '<ul class="toolbar-item-menu" style="display: none;">';
			foreach ($actionEntries as $linkConf) {
				$actionMenu[] = '<li><a href="#" onclick="if(confirm(\'Starten\')) new AutomatorBackend().startAction('.$linkConf[0].'); return false;">' . $linkConf[3] .
					htmlspecialchars($linkConf[1]) . '</a></li>';
			}

			$actionMenu[] = '</ul>';
			return implode("\n", $actionMenu);
		} else {
			return '';
		}


	}

	/**
	 * gets the entries for the action menu
	 *
	 * @return	array	array of action menu entries
	 * @author	Steffen Kamper <info@sk-typo3.de>
	 * @author	Ingo Renner <ingo@typo3.org>
	 */
	protected function getActionEntries() {
		$actions = array();
		
		if ($GLOBALS['BE_USER']->isAdmin()) {
			$queryResource = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
				'*',
				'tx_automator_actions',
				'startoption IN (0,2) AND deleted=0'.t3lib_BEfunc::BEenableFields('tx_automator_actions')
			);
			
		} else {
			$groupList = 0;
			if ($GLOBALS['BE_USER']->groupList) {
				$groupList = $GLOBALS['BE_USER']->groupList;
			}
			
			// Gruppe hier mit bercksichtigen

			$queryResource = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
				'*',
				'tx_automator_actions',
				'startoption IN (0,2) AND deleted=0'.t3lib_BEfunc::BEenableFields('tx_automator_actions')
			);
		}

		if ($queryResource) {
			while ($actionRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($queryResource)) {
				$actions[] = array(
					$actionRow['uid'],
					$actionRow['title'].' - 23.04.1987 23:34',
					'sysext/taskcenter/task/index.php?SET[function]=tx_sysaction&sys_action_uid=' . $actionRow['uid'],
					t3lib_iconworks::getIconImage(
						'tx_automator_actions',
						$actionRow,
						$GLOBALS['BACK_PATH'],
						'hspace="2" class="absmiddle"'
					),
				);
			}

			$GLOBALS['TYPO3_DB']->sql_free_result($queryResource);
		}

		return $actions;
	}

	/**
	 * returns additional attributes for the list item in the toolbar
	 *
	 * @return	string	list item HTML attibutes
	 */
	public function getAdditionalAttributes() {
		// Hack for the Action Loader
		return ' id="tx_automator_menu_runner" style="display: none;"><iframe name="tx_automator_runAction" src="ajax.php?ajaxID=tx_automator_Ajax::runAction" width="200" height="24" scrolling="no" marginheight="0" marginwidth="0" frameborder="0"></iframe></li><li id="tx-automator-menu"';
	}

	/**
	 * adds the neccessary javascript ot the backend
	 *
	 * @return	void
	 */
	protected function addJavascriptToBackend() {
		$this->backendReference->addJavascriptFile(
			t3lib_extMgm::extRelPath($this->EXTKEY) . 'toolbarmenu/tx_automator.js'
		);
	}

	/**
	 * adds the neccessary css ot the backend
	 *
	 * @return	void
	 */
	protected function addCssToBackend() {
		$this->backendReference->addCssFile(
			'automator',
			t3lib_extMgm::extRelPath($this->EXTKEY) .
				'toolbarmenu/tx_automator.css'
		);
	}

	/**
	 * Checks if user has access to the sys action menu
	 *
	 * @return	boolean	true if the user has access, false otherwise
	 */
	public function checkAccess() {
			// taskcenter is enabled for everybody
		return true;
	}
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/toolbarmenu/class.tx_automator_ToolBarMenu.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/automator/toolbarmenu/class.tx_automator_ToolBarMenu.php']);
}

?>
